@@ -225,7 +225,7 @@ class MinimalBot(commands.AutoShardedBot):
         async with self.session.post("https://voxelfox.co.uk/discord/chatlog", json=data) as r:
             return await r.text()
 
-    async def create_global_application_command(self, command: interactions.ApplicationCommand) -> None:
+    async def create_global_application_command(self, command: interactions.ApplicationCommand) -> interactions.ApplicationCommand:
         """
         Add a global slash command for the bot.
 
@@ -238,10 +238,11 @@ class MinimalBot(commands.AutoShardedBot):
             'POST', '/applications/{application_id}/commands',
             application_id=application_id,
         )
-        return await self.http.request(r, json=command.to_json())
+        data = await self.http.request(r, json=command.to_json())
+        return interactions.ApplicationCommand.from_data(data)
 
     async def create_guild_application_command(
-            self, guild: discord.Guild, command: interactions.ApplicationCommand) -> None:
+            self, guild: discord.Guild, command: interactions.ApplicationCommand) -> interactions.ApplicationCommand:
         """
         Add a guild-level slash command for the bot.
 
@@ -255,10 +256,11 @@ class MinimalBot(commands.AutoShardedBot):
             'POST', '/applications/{application_id}/guilds/{guild_id}/commands',
             application_id=application_id, guild_id=guild.id,
         )
-        return await self.http.request(r, json=command.to_json())
+        data = await self.http.request(r, json=command.to_json())
+        return interactions.ApplicationCommand.from_data(data)
 
     async def bulk_create_global_application_commands(
-            self, commands: typing.List[interactions.ApplicationCommand]) -> None:
+            self, commands: typing.List[interactions.ApplicationCommand]) -> typing.List[interactions.ApplicationCommand]:
         """
         Bulk add a global slash command for the bot.
 
@@ -272,10 +274,11 @@ class MinimalBot(commands.AutoShardedBot):
             'PUT', '/applications/{application_id}/commands',
             application_id=application_id,
         )
-        return await self.http.request(r, json=[i.to_json() for i in commands])
+        data = await self.http.request(r, json=[i.to_json() for i in commands])
+        return [interactions.ApplicationCommand.from_data(i) for i in data]
 
     async def bulk_create_guild_application_commands(
-            self, guild: discord.Guild, commands: typing.List[interactions.ApplicationCommand]) -> None:
+            self, guild: discord.Guild, commands: typing.List[interactions.ApplicationCommand]) -> typing.List[interactions.ApplicationCommand]:
         """
         Bulk add a guild-level slash command for the bot.
 
@@ -290,7 +293,8 @@ class MinimalBot(commands.AutoShardedBot):
             'PUT', '/applications/{application_id}/guilds/{guild_id}/commands',
             application_id=application_id, guild_id=guild.id,
         )
-        return await self.http.request(r, json=[i.to_json() for i in commands])
+        data = await self.http.request(r, json=[i.to_json() for i in commands])
+        return [interactions.ApplicationCommand.from_data(i) for i in data]
 
     async def get_global_application_commands(self) -> typing.List[interactions.ApplicationCommand]:
         """
@@ -412,12 +416,13 @@ class MinimalBot(commands.AutoShardedBot):
         content = str(content) if content is not None else None
         if embed is not None and embeds is not None:
             raise discord.InvalidArgument('cannot pass both embed and embeds parameter to send()')
-        if embed:
+        if embed is not None:
             embeds = [embed]
+            embed = None
         if embeds and len(embeds) > 10:
             raise discord.InvalidArgument('embeds parameter must be a list of up to 10 elements')
         if embeds:
-            embeds = [embed.to_dict() for embed in embeds]
+            embeds = [e.to_dict() for e in embeds]
 
         # Work out our allowed mentions
         if allowed_mentions is not None:
@@ -465,6 +470,10 @@ class MinimalBot(commands.AutoShardedBot):
             elif not messageable._sent_ack_response:
                 r = discord.http.Route('POST', '/interactions/{interaction_id}/{token}/callback', interaction_id=channel[0], token=channel[2])
 
+            # A fallback for if someone says no wait but they HAVE sent an ack
+            else:
+                r = discord.http.Route('POST', '/webhooks/{app_id}/{token}', app_id=channel[1], token=channel[2])
+
             # Sent a defer that we should edit
             if wait and messageable.ACK_IS_EDITABLE and messageable._sent_ack_response and not messageable._sent_message_response:
                 r = discord.http.Route('PATCH', '/webhooks/{app_id}/{token}/messages/@original', app_id=channel[1], token=channel[2])
@@ -524,7 +533,7 @@ class MinimalBot(commands.AutoShardedBot):
                 for f in files:
                     f.close()
         else:
-            if wait is False:
+            if wait is False and messageable._sent_ack_response is False:
                 payload = {"type": _no_wait_response_type, "data": payload.copy()}
             response_data = await messageable._state.http.request(r, json=payload)
 
@@ -815,9 +824,6 @@ class Bot(MinimalBot):
         self.guild_settings.clear()
         self.user_settings.clear()
 
-        # Grab the application ID if we need it
-        await self.get_application_id()
-
         # Get database connection
         db = await self.database.get_connection()
 
@@ -1299,6 +1305,18 @@ class Bot(MinimalBot):
         else:
             self.logger.info("Not running bot startup method due to database being disabled")
 
+        # Get the recommended shard count for this bot
+        async with aiohttp.ClientSession() as session:
+            async with session.get("https://discord.com/api/v9/gateway/bot", headers={"Authorization": f"Bot {self.config['token']}"}) as r:
+                data = await r.json()
+        recommended_shard_count = data['shards']
+        self.logger.info(f"Recommended shard count for this bot: {recommended_shard_count}")
+        if recommended_shard_count / 2 > self.shard_count:
+            self.logger.warning((
+                f"The shard count for this bot ({self.shard_count}) is significantly "
+                f"lower than the recommended number {recommended_shard_count}."
+            ))
+
         # And run the original
         self.logger.info("Running original D.py start method")
         await super().start(token or self.config['token'], *args, **kwargs)
@@ -1317,15 +1335,6 @@ class Bot(MinimalBot):
         await self.set_default_presence()
         self.logger.info('Bot loaded.')
 
-        # Get the recommended shard count for this bot
-        recommended_shard_count, _ = await self.http.get_bot_gateway()
-        self.logger.info(f"Recommended shard count for this bot: {recommended_shard_count}")
-        if recommended_shard_count / 2 > self.shard_count:
-            self.logger.warning((
-                f"The shard count for this bot ({self.shard_count}) is significantly "
-                f"lower than the recommended number {recommended_shard_count}."
-            ))
-
     async def invoke(self, ctx):
         """:meta private:"""
 
